@@ -237,6 +237,12 @@ where
         item
     }
 
+    /// Clear the collection
+    pub fn clear(&mut self) {
+        self.set_length(0);
+        self.set_offset(0);
+    }
+
     /// Set the length of the collection
     fn set_length(&mut self, len: u32) {
         self.storage.set(LEN_KEY, &len.to_be_bytes());
